package cn.iocoder.yudao.module.member.dal.mysql.user;

import cn.iocoder.yudao.framework.common.util.spring.enums.CommonStatusEnum;
import cn.iocoder.yudao.framework.mybatis.core.mapper.BaseMapperX;
import cn.iocoder.yudao.module.member.controller.admin.user.vo.UserBackVO;
import cn.iocoder.yudao.module.member.dal.dataobject.user.MemberUserDO;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import org.apache.ibatis.annotations.*;
import org.apache.ibatis.annotations.Param;

import java.util.Collection;
import java.util.List;

/**
 * 会员 User Mapper
 *
 * @author 捷道源码
 */
@Mapper
public interface MemberUserMapper extends BaseMapperX<MemberUserDO> {

    default MemberUserDO selectByMobile(String mobile) {
        return selectOne(MemberUserDO::getMobile, mobile, MemberUserDO::getStatus, CommonStatusEnum.ENABLE.getStatus());
    }

    default MemberUserDO selectByMobile(String areaCode, String mobile) {
        return selectOne(MemberUserDO::getAreaCode, areaCode, MemberUserDO::getMobile, mobile, MemberUserDO::getStatus, CommonStatusEnum.ENABLE.getStatus());
    }


    IPage<MemberUserDO> getPage(IPage<MemberUserDO> page,
                                @Param(Constants.WRAPPER) Wrapper<MemberUserDO> queryWrapper);

    List<MemberUserDO> getList(@Param(Constants.WRAPPER) Wrapper<MemberUserDO> queryWrapper);

    long memberUserCount(@Param(Constants.WRAPPER) Wrapper<MemberUserDO> queryWrapper);

    @ResultType(Integer.class)
    @Select({
            "<script>",
            "select count(1) ",
            "from ecw_order_cargo_control occ",
            "join ecw_order o on occ.order_id = o.order_id ",
            "where occ.is_actual = 1",
            "and occ.deleted = 0 ",
            "and o.deleted = 0 ",
            "AND o.in_warehouse_state != 211 ",
            "AND o.in_warehouse_state != 208 and o.status != 10 ",
            "<when test = 'type != 1 '>",
            "and o.cargo_control_status != 1 ",
            "</when>",
            "AND o.is_cargo_control = 1 ",
            "and occ.`phone` = #{phone} ",
            "</script>"
    })
    Integer appCargoControlCount(@Param("userId") Long userId, @Param("phone") String phone, @Param("type") Integer type);

    @ResultType(Integer.class)
    @Select({
            "<script>",
            "select count(1) ",
            "from ecw_order o ",
            "left join ecw_order_consignor nor on nor.order_id = o.order_id ",
            "where ",
            "o.deleted = 0 ",
            "AND o.in_warehouse_state != 211 ",
            "AND o.in_warehouse_state != 208 and o.status != 10 ",
            "and (o.user_id = #{userId} ",
            "<if test='customerContactsIds != null and customerContactsIds.size() != 0'>",
            "or nor.customer_contacts_id in ",
            "<foreach item='customerContactsId' index='index' collection='customerContactsIds' open='(' separator=',' close=')'>#{customerContactsId}</foreach>",
            "</if>",
            "or nor.phone = #{phone} )",
            "</script>"
    })
    Integer appIssuedOrderCount(@Param("phone") String phone, @Param("userId") Long userId, @Param("customerContactsIds") Collection<Long> customerContactsIds);

    @ResultType(Integer.class)
    @Select({
            "<script>",
            "select count(1) ",
            "from ecw_order o",
            "join ecw_order_consignee nee ON o.order_id = nee.order_id",
            "where ",
            "o.deleted = 0 ",
            "AND o.in_warehouse_state != 211 ",
            "AND o.in_warehouse_state != 208 and o.status != 10 ",
            "and (nee.phone = #{phone}",
            "<if test='customerContactsIds != null and customerContactsIds.size() != 0'>",
            "or nee.customer_contacts_id in ",
            "<foreach item='customerContactsId' index='index' collection='customerContactsIds' open='(' separator=',' close=')'>#{customerContactsId}</foreach>",
            "</if>)",
            "</script>"
    })
    Integer appReceivedOrderCount(@Param("phone") String phone,  @Param("customerContactsIds") Collection<Long> customerContactsIds);

    @ResultType(Integer.class)
    @Select({
            "<script>",
            "select count(1) ",
            "from ecw_order o ",
            "left join ecw_order_cargo_control occ on (occ.order_id = o.order_id and occ.is_actual = 1) ",
            "left join ecw_order_consignee nee on nee.order_id = o.order_id ",
            "left join ecw_order_consignor nor on nor.order_id = o.order_id ",
            "where ",
            "o.deleted = 0 ",
            "AND o.in_warehouse_state != 211 ",
            "AND o.in_warehouse_state != 208 and o.status != 10 ",
            "and (o.user_id = #{userId} ",
            "<if test='customerContactsIds != null and customerContactsIds.size() != 0'>",
            "or nee.customer_contacts_id in ",
            "<foreach item='customerContactsId' index='index' collection='customerContactsIds' open='(' separator=',' close=')'>#{customerContactsId}</foreach>",
            "</if>",
            "or nee.phone = #{phone} ",
            "<if test='customerContactsIds != null and customerContactsIds.size() != 0'>",
            "or nor.customer_contacts_id in ",
            "<foreach item='customerContactsId' index='index' collection='customerContactsIds' open='(' separator=',' close=')'>#{customerContactsId}</foreach>",
            "</if>",
            "or nor.phone = #{phone} ",
            "or occ.`phone` = #{phone} )",
            "</script>"
    })
    Integer appAllOrderCount(@Param("userId") Long userId, @Param("phone") String phone, @Param("customerContactsIds") Collection<Long> customerContactsIds);

    default MemberUserDO selectByEmail(String email) {
        return selectOne(MemberUserDO::getEmail, email);
    }

    List<UserBackVO> get7daysCount(String format);

    IPage<MemberUserDO> getWaitApproveUserPage(IPage<MemberUserDO> page,
                                               @Param(Constants.WRAPPER) Wrapper<MemberUserDO> queryWrapper);

    @Update("update member_user u " +
            "inner join ecw_customer_contacts cc on cc.userid = u.id  " +
            "inner join ecw_customer c on c.id = cc.customer_id " +
            "set u.customer_status = #{customerStatus}, u.is_deal = #{isDeal} " +
            "where c.id = #{customerId}")
    void updateMemberUserDealStatus(@Param("customerId") Long customerId, @Param("customerStatus") Integer customerStatus, @Param("isDeal") Boolean isDeal);

    @ResultType(MemberUserDO.class)
    @Select({
            "<script>",
            "select u.*, ",
            "e.company_name as enterprise_name, " ,
            "e.company_en_name as enterprise_name_en, ",
            "e.company_desc as enterprise_desc, ",
            "e.company_website as enterprise_website, ",
            "e.company_address as enterprise_address, ",
            "e.company_stall as enterprise_stall, ",
            "e.company_band as enterprise_brand, ",
            "uca.`status` as identity_audit_status," ,
            " uca.`audit_remark` as identity_audit_remark," ,
            " uca.`name` as identity_name,",
            " uca.`create_time` as identity_audit_create_time,",
            " uca.`audit_time` as identity_audit_time,",
            " uea.`status` as enterprise_audit_status,",
            " uea.`name` as enterprise_name,",
            " uea.`create_time` as enterprise_audit_create_time,",
            " uea.`audit_time` as enterprise_audit_time," ,
            " uea.`audit_remark` as enterprise_audit_remark,",
            " ec.id as customerId,",
            " ec.number as customerCode,",
            " u.code as memberCode,",
            " er.title_zh as countryTitleZh,",
            " er.title_en as countryTitleEn,",
            " ert.title_zh as cityTitleZh,",
            " ert.title_en as cityTitleEn,",
            " ifnull( mus.`hold_score`, 0) as hold_score,",
            " ifnull( mus.`used_score`, 0) as used_score,",
            " ifnull( mus.`expired_score`, 0) as expired_score",
            "from member_user u ",
            "left join member_user_enterprise e on e.user_id = u.id and e.deleted = 0 ",
            "left join member_user_card_auth uca on u.id = uca.user_id and uca.deleted = 0 " ,
            "left join member_user_enterprise_auth uea on u.id = uea.user_id and uea.deleted = 0 ",
            "left join member_user_score mus on u.id = mus.member_id and mus.deleted = 0 ",
            "left join ecw_customer_contacts ecc on u.id = ecc.userid and ecc.is_default = 1 and ecc.deleted = 0",
            "left join ecw_customer ec on ecc.customer_id = ec.id and ec.deleted = 0",
            "left join ecw_region er on er.id = u.country",
            "left join ecw_region ert on ert.id = u.city",
            "where ",
            "u.deleted = 0 ",
            "AND u.id = #{id} ",
            "</script>"
    })
    List<MemberUserDO> info(@Param("id") Long id);
    @Update("update ecw_customer_contacts set userid = null where userid = #{userId}")
    void unbindingCustomer(@Param("userId") Long userId);

    String getCurrentMaxMemberCode();

    void updateMemberCodeById(@Param("code")String memberCode, @Param("id")Long id);

    void clearMemberCode();
}
