package cn.iocoder.yudao.module.member.vo.scoreRule;

import cn.iocoder.yudao.module.member.vo.scoreRule.extra.ScoreRuleOrderVExtraVO;
import cn.iocoder.yudao.module.member.vo.scoreRule.extra.ScoreRuleRegisterExtraVO;
import cn.iocoder.yudao.module.member.vo.scoreRule.extra.ScoreRuleShareExtraVO;
import cn.iocoder.yudao.module.member.vo.scoreRule.extra.ScoreRulerRecommendExtraVO;
import lombok.*;
import java.util.*;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import org.springframework.format.annotation.DateTimeFormat;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

/**
* 积分规则 Base VO，提供给添加、修改、详细的子 VO 使用
* 如果子 VO 存在差异的字段，请不要添加到这里，影响 Swagger 文档生成
*/
@Data
public class ScoreRuleBaseVO {

    @ApiModelProperty(value = "指标类型（1订单V值，2注册，3推荐，4分享）", required = true)
    @NotNull(message = "指标类型不能为空")
    private Integer type;

    @ApiModelProperty(value = "规则标题中文", required = true)
    @NotBlank(message = "规则标题中文不能为空")
    private String titleZh;

    @ApiModelProperty(value = "规则标题英文", required = true)
    @NotNull(message = "规则标题英文不能为空")
    private String titleEn;

    @ApiModelProperty(value = "规则说明中文", required = true)
    @NotNull(message = "规则说明中文不能为空")
    private String descZh;

    @ApiModelProperty(value = "规则说明英文", required = true)
    @NotNull(message = "规则说明英文不能为空")
    private String descEn;

    @ApiModelProperty(value = "封面图中文")
    private String coverImageZh;

    @ApiModelProperty(value = "封面图英文")
    private String coverImageEn;

    @ApiModelProperty(value = "单次获取积分数（订单V值不传）", required = true)
    @Min(value = 0,message = "单次获取积分数不能小于0")
    private Integer getScoreOnce = 0;

    @ApiModelProperty(value = "累积最高积分（注册不传）", required = true)
    @Min(value = 0,message = "累积最高积分不能小于0")
    private Integer maxScoreTotal = 0;

    @ApiModelProperty(value = "活动开始时间", required = true)
    @NotNull(message = "活动开始时间不能为空")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date startTime;

    @ApiModelProperty(value = "活动结束时间", required = true)
    @NotNull(message = "活动结束时间不能为空")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date endTime;

    @ApiModelProperty(value = "积分有效期（天）", required = true)
    @NotNull(message = "积分有效期不能为空")
    @Min(value = 0,message = "积分有效期不能小于0天")
    private Integer scorePeriod;

    @ApiModelProperty(value = "排序值", required = true)
    @NotNull(message = "排序值不能为空")
    private Integer orderNum;

    @ApiModelProperty(value = "是否推送（0是，1否）默认是", required = true)
    @NotNull(message = "是否推送不能为空")
    private Integer pushActivity = 0;

    @ApiModelProperty(value = "展示平台（1后台，2APP，3WEB）可多选，示例（1,2,3）", required = true)
    @NotNull(message = "展示平台不能为空")
    private String showPlatform;

    @ApiModelProperty(value = "活动状态（1已启用，2未启用，3已关闭，4已过期）", required = true)
    @NotNull(message = "活动状态不能为空")
    private Integer status;

    @ApiModelProperty(value = "订单V值扩展字段")
    private ScoreRuleOrderVExtraVO extraOrderV;
    @ApiModelProperty(value = "注册扩展字段")
    private ScoreRuleRegisterExtraVO extraRegister;
    @ApiModelProperty(value = "推荐扩展字段")
    private ScoreRulerRecommendExtraVO extraRecommend;
    @ApiModelProperty(value = "分享扩展字段")
    private ScoreRuleShareExtraVO extraShare;
}
